#!/usr/bin/env python
# -*- coding: UTF-8 -*-

import optparse, os

TEMPLATE = """%(minute)s %(heure)s * * * root /usr/share/eole/controlevnc/stop_all_stations.sh
"""
CRON_FILE = "/etc/cron.d/arret_stations"


def active(minute, heure):
    if minute != '*':
        if not 0 <= int(minute) <= 59:
            raise Exception("minutes entre 0 et 59")
    if heure != '*':
        if not 0 <= int(heure) <= 23:
            raise Exception("heures entre 0 et 23")
    txt = TEMPLATE % {'minute': str(minute), 'heure':  str(heure)}
    file(CRON_FILE, 'w').write(txt)

def desactive():
    if os.path.exists(CRON_FILE):
        os.remove(CRON_FILE)

def autopad(i):
    if len(i) == 1 and i != '*':
        i = '0'+i
    return i

def affiche():
    t = [None, None]
    if os.path.exists(CRON_FILE):
        txt = file(CRON_FILE).readlines()[0].split()
        t = [autopad(i) for i in txt[:2]]
    return t

def parse_cmdline():
    parser = optparse.OptionParser(conflict_handler="resolve", version = "%prog 2.2")

    parser.add_option('-h', '--heure', dest = "heure",
                  help=u"""heure à laquelle les stations clientes doivent être arrêtées""")

    parser.add_option('-a', '--affiche', dest = "affiche", action="store_true", default=False,
                  help=u"""Affiche l'horaire de l'arrêt programmé des stations clientes""")

    parser.add_option('-d', '--desactive', dest = "desactive", action="store_true", default=False,
                  help=u"""désactive l'arrêt programmé des stations clientes""")

    (options, args) = parser.parse_args()
    if len(args) != 0:
        parser.error("La commande n'accepte aucun argument !")
    if not options.heure and not options.desactive and not options.affiche:
        parser.error("Il manque une option !")

    return options, args

def main():
    options, args = parse_cmdline()
    if options.heure:
        active(0, options.heure)
    elif options.desactive:
        desactive()
        print "Arrêt programmé des stations clientes désactivé."
    elif options.affiche:
        minute, heure = affiche()
        if not minute:
            print "Aucun arrêt programmé"
        else:
            print "Arrêt des station clientes programmé tous les jours à %s:%s"%(heure, minute)

if __name__ == "__main__":
    main()
