# -*- coding: UTF-8 -*-

###########################################################################
# Eole NG - 2010
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
#
# ldap_utils.py
#
# Librairie pour la gestion des requetes LDAP
#
###########################################################################

from scribe.eolegroup import Group
from scribe.eoleldap import LdapEntry
from scribe.eoleuser import User
from scribe.backend import get_workstations

###########
# Groupes #
###########
def get_groupes(gtype='', banned=True):
    """
    renvoie les groupes selon certains critères
    """
    banned_groups = ['DomainAdmins', 'DomainComputers', 'DomainUsers',
                     'PrinterAdmins', 'PrintOperators']
    grp = Group()
    liste_group = grp.get_groups(gtype)
    if banned:
        for banned_group in banned_groups:
            if banned_group in liste_group:
                liste_group.remove(banned_group)
    liste_group.sort()
    return liste_group

def get_classes():
    """
    renvoie la liste des classes
    """
    return get_groupes('classe')

def get_niveau():
    """
    renvoie la liste des niveaux
    """
    return get_groupes('niveau')

def get_classes_et_groupes():
    """
    renvoie la liste des classes et des groupes de travail
    """
    res = get_classes()
    res.extend(get_groupes('groupe'))
    return res

def get_membres(groupe):
    """
    renvoie la liste des membres d'un groupe
    """
    entry = LdapEntry()
    return entry.get_members(groupe)

def get_membres_croise(groupes):
    """
    renvoie les membres de groupe qui sont aussi dans rgroupe
    """
    membres = get_membres(groupes[0])
    for grp in groupes[1:]:
        mem = get_membres(grp)
        membres = list(set(membres).intersection(set(mem)))
    return membres

def get_nb_membres(groupe):
    """
    renvoie le nombre d'inscrit à un ou plusieurs groupes
    """
    if type(groupe) == list or type(groupe) == tuple:
        return len(get_membres_croise(groupe))
    else:
        return len(get_membres(groupe))

################
# utilisateurs #
################
def get_user_groups(user):
    """
    renvoie la liste des groupes de l'utilisateur
    """
    # FIXME : autres attributs dans la méthode
    usr = User()
    return usr.get_user_groups(user)

# FIXME : utilisé ?
#def get_user_shares(user):

# FIXME : utilisé ?
#def get_user_homedrive(user):

def get_simple_attr(user, attr):
    """
    renvoie un attribut utilisateur mono-valué
    """
    usr = User()
    try:
        return usr.get_attr(user, attr)[0]
    except:
        raise Exception('Utilisateur %s non trouvé' % user)

def get_user_sid(user):
    """
    renvoie le SID de l'utilisateur
    """
    return get_simple_attr(user, 'sambaSID')

def get_user_long_name(user):
    """
    renvoie le nom complet d'un utilisateur
    """
    return get_simple_attr(user, 'displayName')

def is_prof(user):
    """
    vérifie que l'utilisateur est un professeur
    """
    return 'professeurs' in get_user_groups(user)

def is_eleve(user):
    """
    vérifie que l'utilisateur est un élève
    """
    return 'eleves' in get_user_groups(user)

############
# partages #
############
# FIXME : utilisé ?
#def get_shares():

############
# Machines #
############
def get_machines():
    """
    renvoie la liste des stations
    """
    # FIXME backend.py est deprécié !
    return get_workstations()

